@@ -105,9 +105,9 @@ class Listpg:
             
     
     async def add(self, **opt):
-        one_column = f"{opt.keys()[0]} = array_append({opt.keys()[0]}, $1)"
-        enums = enumerate(opt.keys(), 2)
-        columns = ' AND '.join(f'{c} = ${i}' for i, c in enums)
+        one_column = f"{list(opt.keys())[0]} = array_append({list(opt.keys())[0]}, $1)"
+        enums = enumerate(opt.keys(), 1)
+        columns = ' AND '.join(f'{c} = ${i}' for i, c in enums if i != 1) 
 
         await self.pool.execute(f'UPDATE {self.table} SET {one_column} WHERE {columns}', *opt.values())
 
